summaryrefslogtreecommitdiff
path: root/Build
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2019-11-24 21:34:37 +0000
committerKarl Berry <karl@freefriends.org>2019-11-24 21:34:37 +0000
commit4496f7ad4bfd0f0ac5de285d257f704a4666a496 (patch)
treee85528f9abc73b8a8c5ee31b13af4df1d18fc0db /Build
parenta6a6f0433fec0714e037a4ccfc5d67092535a128 (diff)
attachfile2 splt from oberdiek (24nov19)
git-svn-id: svn://tug.org/texlive/trunk@52909 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Build')
-rw-r--r--Build/source/texk/texlive/linked_scripts/Makefile.am2
-rw-r--r--Build/source/texk/texlive/linked_scripts/Makefile.in2
-rwxr-xr-xBuild/source/texk/texlive/linked_scripts/attachfile2/pdfatfi.pl (renamed from Build/source/texk/texlive/linked_scripts/oberdiek/pdfatfi.pl)15
-rw-r--r--Build/source/texk/texlive/linked_scripts/scripts.lst2
4 files changed, 10 insertions, 11 deletions
diff --git a/Build/source/texk/texlive/linked_scripts/Makefile.am b/Build/source/texk/texlive/linked_scripts/Makefile.am
index 61502a3b3ff..6cff2f81b03 100644
--- a/Build/source/texk/texlive/linked_scripts/Makefile.am
+++ b/Build/source/texk/texlive/linked_scripts/Makefile.am
@@ -83,6 +83,7 @@ texmf_other_scripts = \
accfonts/vpl2ovp \
accfonts/vpl2vpl \
arara/arara.sh \
+ attachfile2/pdfatfi.pl \
authorindex/authorindex \
bib2gls/bib2gls.sh \
bib2gls/convertgls2bib.sh \
@@ -157,7 +158,6 @@ texmf_other_scripts = \
multibibliography/multibibliography.pl \
musixtex/musixflx.lua \
musixtex/musixtex.lua \
- oberdiek/pdfatfi.pl \
pax/pdfannotextractor.pl \
pdfcrop/pdfcrop.pl \
pdflatexpicscale/pdflatexpicscale.pl \
diff --git a/Build/source/texk/texlive/linked_scripts/Makefile.in b/Build/source/texk/texlive/linked_scripts/Makefile.in
index 110763c2f96..35e6ba1e75b 100644
--- a/Build/source/texk/texlive/linked_scripts/Makefile.in
+++ b/Build/source/texk/texlive/linked_scripts/Makefile.in
@@ -296,6 +296,7 @@ texmf_other_scripts = \
accfonts/vpl2ovp \
accfonts/vpl2vpl \
arara/arara.sh \
+ attachfile2/pdfatfi.pl \
authorindex/authorindex \
bib2gls/bib2gls.sh \
bib2gls/convertgls2bib.sh \
@@ -370,7 +371,6 @@ texmf_other_scripts = \
multibibliography/multibibliography.pl \
musixtex/musixflx.lua \
musixtex/musixtex.lua \
- oberdiek/pdfatfi.pl \
pax/pdfannotextractor.pl \
pdfcrop/pdfcrop.pl \
pdflatexpicscale/pdflatexpicscale.pl \
diff --git a/Build/source/texk/texlive/linked_scripts/scripts.lst b/Build/source/texk/texlive/linked_scripts/scripts.lst
index ff05ce62779..7dc16acdff5 100644
--- a/Build/source/texk/texlive/linked_scripts/scripts.lst
+++ b/Build/source/texk/texlive/linked_scripts/scripts.lst
@@ -26,6 +26,7 @@ accfonts/mkt1font
accfonts/vpl2ovp
accfonts/vpl2vpl
arara/arara.sh
+attachfile2/pdfatfi.pl
authorindex/authorindex
bib2gls/bib2gls.sh
bib2gls/convertgls2bib.sh
@@ -100,7 +101,6 @@ mkpic/mkpic
multibibliography/multibibliography.pl
musixtex/musixflx.lua
musixtex/musixtex.lua
-oberdiek/pdfatfi.pl
pax/pdfannotextractor.pl
pdfcrop/pdfcrop.pl
pdflatexpicscale/pdflatexpicscale.pl
diff --git a/Build/source/texk/texlive/linked_scripts/oberdiek/pdfatfi.pl b/Build/source/texk/texlive/linked_scripts/attachfile2/pdfatfi.pl
index 50e9f856042..f12381a6064 100755
--- a/Build/source/texk/texlive/linked_scripts/oberdiek/pdfatfi.pl
+++ b/Build/source/texk/texlive/linked_scripts/attachfile2/pdfatfi.pl
@@ -19,9 +19,8 @@ $^W=1; # turn warning on
# This work has the LPPL maintenance status "maintained".
#
# The Current Maintainers of this work are
-Heiko Oberdiek and the Oberdiek Package Support Group
-https://github.com/ho-tex/oberdiek/issues
-
+# Heiko Oberdiek and the Oberdiek Package Support Group
+# https://github.com/ho-tex/attachfile2/issues
#
# See file "attachfile2.pdf" for a list of files that belong to
# this project.
@@ -33,7 +32,7 @@ my $prj = 'pdfatfi';
my $file = "$prj.pl";
my $program = uc($&) if $file =~ /^\w+/;
my $version = "2.9";
-my $date = "2019/07/24";
+my $date = "2019/11/24";
my $author = "Heiko Oberdiek";
my $copyright = "Copyright (c) 2005-2010, 2012 by $author.";
#
@@ -42,7 +41,7 @@ my $copyright = "Copyright (c) 2005-2010, 2012 by $author.";
# 2006/08/16 v2.2: Included in DTX file of attachfile2.dtx.
# 2010/09/27 v2.6: Keys ModDateTZ and CreationDateTZ added.
# 2016/05/16 v2.8: Option --version added.
# 2019/07/24 v2.9: adapted version to attachfile2 version.
#
use POSIX qw(strftime); # %z is used (GNU)
@@ -145,9 +144,9 @@ while(<IN>) {
print "!!! Warning: File `$file' not found!\n";
}
else {
- my $size = @s[7];
- my $mtime = @s[9];
- my $ctime = @s[10]; # inode change time
+ my $size = $s[7];
+ my $mtime = $s[9];
+ my $ctime = $s[10]; # inode change time
my ($sec, $min, $hour, $mday, $mon, $year) =
localtime($mtime);
@@ -42,7 +41,7 @@ my $copyright = "Copyright (c) 2005-2010, 2012 by $author.";
# 2010/09/27 v2.6: Keys ModDateTZ and CreationDateTZ added.
# 2016/05/16 v2.8: Option --version added.
-# 2019/07/24 v2.9: adapted version to attachfile2 version.
+# 2019/11/24 v2.10: adapted version to attachfile2 version.
#
use POSIX qw(strftime); # %z is used (GNU)